==> monet-1.0.31-sources.jar: io/intino/monet/box/ui/displays/templates/AbstractAppTemplate.java <==
package io.intino.monet.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.monet.box.ui.*;

import io.intino.monet.box.MonetBox;

import io.intino.monet.box.ui.displays.templates.*;






import io.intino.monet.box.ui.displays.items.*;

import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractAppTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Header header;
	public _15_1_1222698125 _15_1_1222698125;
	public AppTemplate._15_1_1222698125. Loading loading;
	public AppTemplate._15_1_1222698125.Loading. _16_57_039976812 _16_57_039976812;
	public AppTemplate._15_1_1222698125. OrderTypesPage orderTypesPage;
	public OrderTypesTemplate orderTypesStamp;
	public AppTemplate._15_1_1222698125. OrderPage orderPage;
	public OrderTemplate orderStamp;

    public AbstractAppTemplate(B box) {
        super(box);
        id("appTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (header == null) header = register(new Header((MonetBox)box()).id("a795989040"));
		if (_15_1_1222698125 == null) _15_1_1222698125 = register(new _15_1_1222698125(box()).<_15_1_1222698125>id("a342695501").owner(AbstractAppTemplate.this));
		if (_15_1_1222698125 != null) loading = _15_1_1222698125.loading;
		if (loading != null) _16_57_039976812 = _15_1_1222698125.loading._16_57_039976812;
		if (_15_1_1222698125 != null) orderTypesPage = _15_1_1222698125.orderTypesPage;
		if (orderTypesPage != null) orderTypesStamp = _15_1_1222698125.orderTypesPage.orderTypesStamp;
		if (_15_1_1222698125 != null) orderPage = _15_1_1222698125.orderPage;
		if (orderPage != null) orderStamp = _15_1_1222698125.orderPage.orderStamp;
	}

    @Override
    public void remove() {
        super.remove();
	    if (header != null) header.unregister();
	    if (_15_1_1222698125 != null) _15_1_1222698125.unregister();
	}

	public class _15_1_1222698125 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public AppTemplate._15_1_1222698125. Loading loading;
		public AppTemplate._15_1_1222698125. OrderTypesPage orderTypesPage;
		public AppTemplate._15_1_1222698125. OrderPage orderPage;

		public _15_1_1222698125(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (loading == null) loading = register(new Loading(box()).<Loading>id("a_1240687970").owner(AbstractAppTemplate.this));
			if (orderTypesPage == null) orderTypesPage = register(new OrderTypesPage(box()).<OrderTypesPage>id("a9211736").owner(AbstractAppTemplate.this));
			if (orderPage == null) orderPage = register(new OrderPage(box()).<OrderPage>id("a_90574881").owner(AbstractAppTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (loading != null) loading.unregister();
			if (orderTypesPage != null) orderTypesPage.unregister();
			if (orderPage != null) orderPage.unregister();
		}

		public class Loading extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public AppTemplate._15_1_1222698125.Loading. _16_57_039976812 _16_57_039976812;

			public Loading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_16_57_039976812 == null) _16_57_039976812 = register(new _16_57_039976812(box()).<_16_57_039976812>id("a_1667665322").owner(AbstractAppTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_16_57_039976812 != null) _16_57_039976812.unregister();
			}

			public class _16_57_039976812 extends io.intino.alexandria.ui.displays.components.Spinner<io.intino.alexandria.ui.displays.notifiers.SpinnerNotifier, B>  {

				public _16_57_039976812(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}

		public class OrderTypesPage extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
			public OrderTypesTemplate orderTypesStamp;

			public OrderTypesPage(B box) {
				super(box);
			}

			@Override
			public void initConditional() {
				super.init();
				if (orderTypesStamp == null) orderTypesStamp = register(new OrderTypesTemplate((MonetBox)box()).id("a518467025"));
				if (orderTypesStamp == null) orderTypesStamp = _15_1_1222698125.orderTypesPage.orderTypesStamp;
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (orderTypesStamp != null) orderTypesStamp.unregister();
			}
		}

		public class OrderPage extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
			public OrderTemplate orderStamp;

			public OrderPage(B box) {
				super(box);
			}

			@Override
			public void initConditional() {
				super.init();
				if (orderStamp == null) orderStamp = register(new OrderTemplate((MonetBox)box()).id("a_1774927499"));
				if (orderStamp == null) orderStamp = _15_1_1222698125.orderPage.orderStamp;
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (orderStamp != null) orderStamp.unregister();
			}
		}
	}
}

==> monet-1.0.54-sources.jar: io/intino/monet/box/ui/displays/templates/AbstractAppTemplate.java <==
package io.intino.monet.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.monet.box.ui.*;

import io.intino.monet.box.MonetBox;

import io.intino.monet.box.ui.displays.templates.*;






import io.intino.monet.box.ui.displays.items.*;

import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractAppTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Header header;
	public _15_1_1222698125 _15_1_1222698125;
	public AppTemplate._15_1_1222698125. Loading loading;
	public AppTemplate._15_1_1222698125.Loading. _16_57_039976812 _16_57_039976812;
	public AppTemplate._15_1_1222698125. OrderTypesPage orderTypesPage;
	public OrderTypesTemplate orderTypesStamp;
	public AppTemplate._15_1_1222698125. OrderPage orderPage;
	public OrderTemplate orderStamp;

    public AbstractAppTemplate(B box) {
        super(box);
        id("appTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (header == null) header = register(new Header((MonetBox)box()).id("a795989040"));
		if (_15_1_1222698125 == null) _15_1_1222698125 = register(new _15_1_1222698125(box()).<_15_1_1222698125>id("a342695501").owner(AbstractAppTemplate.this));
		if (_15_1_1222698125 != null) loading = _15_1_1222698125.loading;
		if (loading != null) _16_57_039976812 = _15_1_1222698125.loading._16_57_039976812;
		if (_15_1_1222698125 != null) orderTypesPage = _15_1_1222698125.orderTypesPage;
		if (orderTypesPage != null) orderTypesStamp = _15_1_1222698125.orderTypesPage.orderTypesStamp;
		if (_15_1_1222698125 != null) orderPage = _15_1_1222698125.orderPage;
		if (orderPage != null) orderStamp = _15_1_1222698125.orderPage.orderStamp;
	}

    @Override
    public void remove() {
        super.remove();
	    if (header != null) header.unregister();
	    if (_15_1_1222698125 != null) _15_1_1222698125.unregister();
	}

	public class _15_1_1222698125 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public AppTemplate._15_1_1222698125. Loading loading;
		public AppTemplate._15_1_1222698125. OrderTypesPage orderTypesPage;
		public AppTemplate._15_1_1222698125. OrderPage orderPage;

		public _15_1_1222698125(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (loading == null) loading = register(new Loading(box()).<Loading>id("a_1240687970").owner(AbstractAppTemplate.this));
			if (orderTypesPage == null) orderTypesPage = register(new OrderTypesPage(box()).<OrderTypesPage>id("a9211736").owner(AbstractAppTemplate.this));
			if (orderPage == null) orderPage = register(new OrderPage(box()).<OrderPage>id("a_90574881").owner(AbstractAppTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (loading != null) loading.unregister();
			if (orderTypesPage != null) orderTypesPage.unregister();
			if (orderPage != null) orderPage.unregister();
		}

		public class Loading extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public AppTemplate._15_1_1222698125.Loading. _16_57_039976812 _16_57_039976812;

			public Loading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_16_57_039976812 == null) _16_57_039976812 = register(new _16_57_039976812(box()).<_16_57_039976812>id("a_1667665322").owner(AbstractAppTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_16_57_039976812 != null) _16_57_039976812.unregister();
			}

			public class _16_57_039976812 extends io.intino.alexandria.ui.displays.components.Spinner<io.intino.alexandria.ui.displays.notifiers.SpinnerNotifier, B>  {

				public _16_57_039976812(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}

		public class OrderTypesPage extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
			public OrderTypesTemplate orderTypesStamp;

			public OrderTypesPage(B box) {
				super(box);
			}

			@Override
			public void initConditional() {
				super.init();
				if (orderTypesStamp == null) orderTypesStamp = AbstractAppTemplate.this.orderTypesStamp = register(new OrderTypesTemplate((MonetBox)box()).id("a518467025"));
				if (AbstractAppTemplate.this.orderTypesStamp == null) AbstractAppTemplate.this.orderTypesStamp = _15_1_1222698125.orderTypesPage.orderTypesStamp;
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (orderTypesStamp != null) orderTypesStamp.unregister();
			}
		}

		public class OrderPage extends io.intino.alexandria.ui.displays.components.BlockConditional<io.intino.alexandria.ui.displays.notifiers.BlockConditionalNotifier, B>  {
			public OrderTemplate orderStamp;

			public OrderPage(B box) {
				super(box);
			}

			@Override
			public void initConditional() {
				super.init();
				if (orderStamp == null) orderStamp = AbstractAppTemplate.this.orderStamp = register(new OrderTemplate((MonetBox)box()).id("a_1774927499"));
				if (AbstractAppTemplate.this.orderStamp == null) AbstractAppTemplate.this.orderStamp = _15_1_1222698125.orderPage.orderStamp;
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (orderStamp != null) orderStamp.unregister();
			}
		}
	}
}
